==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ComboBoxColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { ComboBoxColumnDescription } from "./ComboBoxColumnDescription";
/**
 * @hidden
 */
var ComboBoxColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ComboBoxColumnDescriptionMetadata, _super);
    function ComboBoxColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ComboBoxColumnDescriptionMetadata.b = function (a) {
        if (ComboBoxColumnDescriptionMetadata.a == null) {
            ComboBoxColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ComboBoxColumnDescriptionMetadata.c(ComboBoxColumnDescriptionMetadata.a);
        }
        if (a.g(ComboBoxColumnDescriptionMetadata.a)) {
            return;
        }
        a.s(ComboBoxColumnDescriptionMetadata.a);
    };
    ComboBoxColumnDescriptionMetadata.c = function (a) {
        ColumnDescriptionMetadata.c(a);
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
        a.item("DataSource", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("TextField", "String");
        a.item("ValueField", "String");
    };
    ComboBoxColumnDescriptionMetadata.d = function (a) {
        ComboBoxColumnDescriptionMetadata.b(a);
        a.u("ComboBoxColumn", function () { return new ComboBoxColumnDescription(); });
        a.t("ComboBoxColumn", ComboBoxColumnDescriptionMetadata.a);
    };
    ComboBoxColumnDescriptionMetadata.$t = markType(ComboBoxColumnDescriptionMetadata, 'ComboBoxColumnDescriptionMetadata');
    ComboBoxColumnDescriptionMetadata.a = null;
    return ComboBoxColumnDescriptionMetadata;
}(Base));
export { ComboBoxColumnDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ComboBoxColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ComboBoxColumnDescription } from "./ComboBoxColumnDescription";
/**
 * @hidden
 */
var ComboBoxColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ComboBoxColumnDescriptionMetadata, _super);
    function ComboBoxColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ComboBoxColumnDescriptionMetadata.b = function (a) {
        if (ComboBoxColumnDescriptionMetadata.a == null) {
            ComboBoxColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ComboBoxColumnDescriptionMetadata.c(ComboBoxColumnDescriptionMetadata.a);
        }
        if (a.j(ComboBoxColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(ComboBoxColumnDescriptionMetadata.a);
    };
    ComboBoxColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
        a.item("DataSource", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("TextField", "String");
        a.item("ValueField", "String");
    };
    ComboBoxColumnDescriptionMetadata.d = function (a) {
        ComboBoxColumnDescriptionMetadata.b(a);
        a.aa("ComboBoxColumn", function () { return new ComboBoxColumnDescription(); });
        a.z("ComboBoxColumn", ComboBoxColumnDescriptionMetadata.a);
    };
    ComboBoxColumnDescriptionMetadata.$t = markType(ComboBoxColumnDescriptionMetadata, 'ComboBoxColumnDescriptionMetadata');
    ComboBoxColumnDescriptionMetadata.a = null;
    return ComboBoxColumnDescriptionMetadata;
}(Base));
export { ComboBoxColumnDescriptionMetadata };
